@@ -17,10 +17,16 @@ d<-dist.matrix[test,train]
 #only need the responses for the training data
 if (length(y)>length(train)) y<-y[train]
 
-#calculate closest neighbors
-d<-t(apply(d,1,function(x) rank(x,ties.method=ties.meth)))
-
+#calculate closest neighbors and
 #return aggregate response for the k closest neighbors
-apply(d,1,function(x) apply(data.frame(y[x<=k]),2,agg.meth))
+if (n==1) {
+  d <- rank(d, ties.method = ties.meth)
+  x <- apply(data.frame(y[d <= k]), 2, agg.meth)
+  names(x) <- test
+  return(x)
+  }
+else {
+  d<-t(apply(d,1,function(x) rank(x,ties.method=ties.meth)))
+  apply(d,1,function(x) apply(data.frame(y[x<=k]),2,agg.meth))
+  }
 }
-
